pub struct Provenance { /* private fields */ }Expand description
Lineage metadata that ties normalized data back to its provider record.
Implementations
Sourceimpl Provenance
impl Provenance
Sourcepub fn builder() -> ProvenanceBuilder
pub fn builder() -> ProvenanceBuilder
Create an instance of Provenance using the builder syntax
Sourceimpl Provenance
impl Provenance
Sourcepub const fn source_system(&self) -> System
pub const fn source_system(&self) -> System
Returns the source system evidence carried by this source-lineage value.
Sourcepub const fn endpoint(&self) -> &Endpoint
pub const fn endpoint(&self) -> &Endpoint
Returns the endpoint evidence carried by this source-lineage value.
Sourcepub const fn provider_record_id(&self) -> &ProviderRecordId
pub const fn provider_record_id(&self) -> &ProviderRecordId
Returns the provider record id evidence carried by this source-lineage value.
Returns the related provider ids evidence carried by this source snapshot.
Sourcepub const fn extraction_batch(&self) -> &ExtractionBatchId
pub const fn extraction_batch(&self) -> &ExtractionBatchId
Returns the extraction batch evidence carried by this source-lineage value.
Sourcepub const fn pulled_at(&self) -> &Timestamp
pub const fn pulled_at(&self) -> &Timestamp
Returns the pulled at evidence carried by this source-lineage value.
Sourcepub const fn raw_payload_ref(&self) -> &RawPayloadRef
pub const fn raw_payload_ref(&self) -> &RawPayloadRef
Returns the raw payload ref evidence carried by this source-lineage value.
Sourcepub fn promote(self) -> Provenance
pub fn promote(self) -> Provenance
Promotes provider source data into the normalized domain snapshot.